@@ -1,6 +1,3 @@
-// Copyright 2018 the Kurbo Authors
-// SPDX-License-Identifier: Apache-2.0 OR MIT
-
 //! SVG path representation.
 
 use std::error::Error;
@@ -68,17 +65,14 @@ impl BezPath {
 
     /// Write the SVG representation of this path to the provided buffer.
     pub fn write_to<W: Write>(&self, mut writer: W) -> io::Result<()> {
-        for (i, el) in self.elements().iter().enumerate() {
-            if i > 0 {
-                write!(writer, " ")?;
-            }
+        for el in self.elements() {
             match *el {
-                PathEl::MoveTo(p) => write!(writer, "M{},{}", p.x, p.y)?,
-                PathEl::LineTo(p) => write!(writer, "L{},{}", p.x, p.y)?,
-                PathEl::QuadTo(p1, p2) => write!(writer, "Q{},{} {},{}", p1.x, p1.y, p2.x, p2.y)?,
+                PathEl::MoveTo(p) => write!(writer, "M{} {}", p.x, p.y)?,
+                PathEl::LineTo(p) => write!(writer, "L{} {}", p.x, p.y)?,
+                PathEl::QuadTo(p1, p2) => write!(writer, "Q{} {} {} {}", p1.x, p1.y, p2.x, p2.y)?,
                 PathEl::CurveTo(p1, p2, p3) => write!(
                     writer,
-                    "C{},{} {},{} {},{}",
+                    "C{} {} {} {} {} {}",
                     p1.x, p1.y, p2.x, p2.y, p3.x, p3.y
                 )?,
                 PathEl::ClosePath => write!(writer, "Z")?,
@@ -249,7 +243,7 @@ impl Display for SvgParseError {
         match self {
             SvgParseError::Wrong => write!(f, "Unable to parse a number"),
             SvgParseError::UnexpectedEof => write!(f, "Unexpected EOF"),
-            SvgParseError::UnknownCommand(letter) => write!(f, "Unknown command, \"{letter}\""),
+            SvgParseError::UnknownCommand(letter) => write!(f, "Unknown command, \"{}\"", letter),
         }
     }
 }
@@ -283,9 +277,9 @@ impl<'a> SvgLexer<'a> {
     fn get_cmd(&mut self, last_cmd: u8) -> Option<u8> {
         self.skip_ws();
         if let Some(c) = self.get_byte() {
-            if c.is_ascii_lowercase() || c.is_ascii_uppercase() {
+            if (b'a'..=b'z').contains(&c) || (b'A'..=b'Z').contains(&c) {
                 return Some(c);
-            } else if last_cmd != 0 && (c == b'-' || c == b'.' || c.is_ascii_digit()) {
+            } else if last_cmd != 0 && (c == b'-' || c == b'.' || (b'0'..=b'9').contains(&c)) {
                 // Plausible number start
                 self.unget();
                 return Some(last_cmd);
@@ -317,7 +311,7 @@ impl<'a> SvgLexer<'a> {
         let mut digit_count = 0;
         let mut seen_period = false;
         while let Some(c) = self.get_byte() {
-            if c.is_ascii_digit() {
+            if (b'0'..=b'9').contains(&c) {
                 digit_count += 1;
             } else if c == b'.' && !seen_period {
                 seen_period = true;
@@ -332,11 +326,11 @@ impl<'a> SvgLexer<'a> {
                 if c == b'-' || c == b'+' {
                     c = self.get_byte().ok_or(SvgParseError::Wrong)?
                 }
-                if c.is_ascii_digit() {
+                if !(b'0'..=b'9').contains(&c) {
                     return Err(SvgParseError::Wrong);
                 }
                 while let Some(c) = self.get_byte() {
-                    if c.is_ascii_digit() {
+                    if !(b'0'..=b'9').contains(&c) {
                         self.unget();
                         break;
                     }
@@ -373,7 +367,7 @@ impl<'a> SvgLexer<'a> {
 
     fn get_maybe_relative(&mut self, cmd: u8) -> Result<Point, SvgParseError> {
         let pt = self.get_number_pair()?;
-        if cmd.is_ascii_lowercase() {
+        if (b'a'..=b'z').contains(&cmd) {
             Ok(self.last_pt + pt.to_vec2())
         } else {
             Ok(pt)
@@ -413,7 +407,8 @@ impl Arc {
         let mut ry = arc.radii.y.abs();
 
         let xr = arc.x_rotation % (2.0 * PI);
-        let (sin_phi, cos_phi) = xr.sin_cos();
+        let cos_phi = xr.cos();
+        let sin_phi = xr.sin();
         let hd_x = (arc.from.x - arc.to.x) * 0.5;
         let hd_y = (arc.from.y - arc.to.y) * 0.5;
         let hs_x = (arc.from.x + arc.to.x) * 0.5;
@@ -528,7 +523,7 @@ mod tests {
         .into()];
         let path = BezPath::from_path_segments(segments.iter().cloned());
 
-        assert_eq!(path.to_svg(), "M10,10 C20,20 30,30 40,40");
+        assert_eq!(path.to_svg(), "M10 10C20 20 30 30 40 40");
     }
 
     #[test]
@@ -551,10 +546,7 @@ mod tests {
         ];
         let path = BezPath::from_path_segments(segments.iter().cloned());
 
-        assert_eq!(
-            path.to_svg(),
-            "M10,10 C20,20 30,30 40,40 C30,30 20,20 10,10"
-        );
+        assert_eq!(path.to_svg(), "M10 10C20 20 30 30 40 40C30 30 20 20 10 10");
     }
 
     #[test]
@@ -579,7 +571,7 @@ mod tests {
 
         assert_eq!(
             path.to_svg(),
-            "M10,10 C20,20 30,30 40,40 M50,50 C30,30 20,20 10,10"
+            "M10 10C20 20 30 30 40 40M50 50C30 30 20 20 10 10"
         );
     }
 
